<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package bestblogger
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
	<head>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="profile" href="https://gmpg.org/xfn/11">

		<?php wp_head(); ?>
	</head>

	<body <?php body_class(); ?>>

		<?php
		if ( function_exists( 'wp_body_open' ) ) {
			wp_body_open();
		}
		?>

		<div id="page" class="site">

			<a class="skip-link screen-reader-text" href="#content">
				<?php esc_html_e( 'Skip to content', 'bestblogger' ); ?>
			</a>

			<header id="masthead" class="site-header">
				<nav id="site-navigation" class="navbar navbar-default" role="navigation">
					<div class="container">
						<div class="navbar-header">

							<button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#primary-menu">
								<span class="icon-bar"></span>
								<span class="icon-bar"></span>
								<span class="icon-bar"></span>
							</button><!-- .navbar-toggle -->

							<?php 
								$bestblogger_description = get_bloginfo( 'description', 'display' ); if(!$bestblogger_description) { $class = ' title-align-center'; }
							?>

							<div class="navbar-brand<?php echo $class; ?>">

								<?php the_custom_logo(); ?>
								
								<h1 class="site-title">
									<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
										<?php echo esc_html(get_bloginfo( 'name', 'display' )); ?>
									</a>
								</h1>

								<?php
								if ( $bestblogger_description || is_customize_preview() ) {
									?>
									<p class="site-description">
										<?php echo esc_html($bestblogger_description); ?>
									</p>
									<?php
								}
								?>

							</div><!-- .navbar-brand -->
						</div><!-- .navbar-header -->

						<div id="primary-menu" class="collapse navbar-collapse">
							<div class="navbar-right">

								<?php
								wp_nav_menu( array(
									'theme_location' => 'primary',
									'container'		 => 'ul',
									'menu_id'		 => 'primary-menu-2',
									'menu_class'	 => 'nav navbar-nav',
								) );
								?>

								<ul class="nav navbar-nav navbar-right search-bar">
		                            <li class="">
		                            	<a href="#toggle-search" class="animate"><i class="fa fa-search"></i> <i class="fa fa-times"></i></a>
		                            </li>                
								</ul>

							</div><!-- .navbar-right -->
						</div><!-- #primary-menu -->
					</div><!-- .container -->
					<div class="bootsnipp-search animate">
			            <div class="container">
							<?php get_search_form(); ?>
			            </div>
			        </div>
				</nav><!-- #site-navigation -->
			</header><!-- #masthead -->

			<div id="content" <?php bestblogger_content_section_class(); ?>>
				<div class="row">
